# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.new_metric_request import NewMetricRequest

class TestNewMetricRequest(unittest.TestCase):
    """NewMetricRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NewMetricRequest:
        """Test NewMetricRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NewMetricRequest`
        """
        model = NewMetricRequest()
        if include_optional:
            return NewMetricRequest(
                type = 'QueryRelevance',
                name = '',
                metric_metadata = '',
                config = arthur_client.api_bindings.models.relevance_metric_config.RelevanceMetricConfig(
                    relevance_threshold = 1.337, 
                    use_llm_judge = True, )
            )
        else:
            return NewMetricRequest(
                type = 'QueryRelevance',
                name = '',
                metric_metadata = '',
        )
        """

    def testNewMetricRequest(self):
        """Test NewMetricRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
