# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.alert_rule import AlertRule

class TestAlertRule(unittest.TestCase):
    """AlertRule unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AlertRule:
        """Test AlertRule
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AlertRule`
        """
        model = AlertRule()
        if include_optional:
            return AlertRule(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                model_id = '',
                name = '',
                description = '',
                threshold = 1.337,
                bound = 'upper_bound',
                query = '',
                metric_name = '',
                interval = arthur_client.api_bindings.models.alert_rule_interval.AlertRuleInterval(
                    unit = 'seconds', 
                    count = 56, ),
                last_updated_by_user = arthur_client.api_bindings.models.user.User(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    organization_id = '', 
                    id = '', 
                    first_name = '', 
                    last_name = '', 
                    email = '', 
                    picture = '', 
                    user_type = 'user', 
                    data_plane_id = '', 
                    client_id = '', 
                    organization_name = '', ),
                notification_webhooks = [
                    arthur_client.api_bindings.models.alert_rule_notification_webhook.AlertRuleNotificationWebhook(
                        id = '', 
                        name = '', )
                    ]
            )
        else:
            return AlertRule(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                model_id = '',
                name = '',
                threshold = 1.337,
                bound = 'upper_bound',
                query = '',
                metric_name = '',
                interval = arthur_client.api_bindings.models.alert_rule_interval.AlertRuleInterval(
                    unit = 'seconds', 
                    count = 56, ),
                notification_webhooks = [
                    arthur_client.api_bindings.models.alert_rule_notification_webhook.AlertRuleNotificationWebhook(
                        id = '', 
                        name = '', )
                    ],
        )
        """

    def testAlertRule(self):
        """Test AlertRule"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
